@@ -511,7 +511,7 @@ class SearchDialog(QDialog, Ui_searchDialog):
         Carries out the search.
         """
         SearchDialog.searchOrder = self.searchOrderSelector.currentIndex()
-        searchString = unicode(self.lineEdit.text(), "utf-8")
+        searchString = unicode(self.lineEdit.text())
         searchDict = {"Date published": "published", "Relevance": "relevance", "View count": "viewCount", "Rating": "rating"}
         searchOrder = searchDict.get(unicode(self.searchOrderButton.valueText()))
         if searchString in SearchDialog.recentSearches:
