@@ -213,9 +213,9 @@ class YouTubeVideoFeed(QThread):
         Retrieves and returns the video feed.
         """
         try:
-            self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(self.videoFeed + "?start-index=%s" % unicode(self.results + 1))
+            self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
         except:
-            self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(self.videoFeed + "&start-index=%s" % unicode(self.results + 1))
+            self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
             
     def getVideoData(self):
         for video in self.ytVideoFeed.entry:
